@@ -2,6 +2,7 @@ from protmo.pm import *
 from protmo.ast import *
 from protmo.grpc_ast import AstToGrpcAst
 from protmo.settings_loader import settings
+from pathlib import Path
 
 
 def create_proto_file(package: str) -> None:
@@ -22,5 +23,7 @@ def create_proto_file(package: str) -> None:
                 content += str(proto_msg) + '\n\n'
                 seen.add(proto_msg.name)
 
-    with open(f'{settings.proto_folder}/{package}.proto', 'w') as f:
+    pwd = Path(settings.proto_folder)
+    pwd.mkdir(exist_ok=True)
+    with open(pwd.jonipath(f'{package}.proto'), 'w') as f:
         f.write(content)
