@@ -17,10 +17,10 @@ class OpenIdConnection:
 
     def __init__(self, realm: str) -> None:
         self.openid = KeycloakOpenID(server_url=settings.keycloak['server_url'],
-            client_id=settings.keycloak['client_id'],
-            verify=settings.keycloak.get('verify', True), # TODO: rather use the Chrome/Curl truststore
+            verify=settings.keycloak.get('verify', True),
             realm_name=realm,
-            client_secret_key=settings.keycloak['client_secret'])
+            client_id=settings.keycloak['client_id'],
+            client_secret_key=settings.keycloak.get('client_secret'))
         self.public_key = "-----BEGIN PUBLIC KEY-----\n" + self.openid.public_key() + "\n-----END PUBLIC KEY-----"
 
 openid_connections = {}
